==> tecfy_corev2_package-1.0.1.tar.gz: lib/views/home/setting.dart <==
part of tecfy_corev2_client_package;

class SettingPage extends StatefulWidget {
  final bool isPopup;
  SettingPage(this.isPopup, {Key? key}) : super(key: key);
  @override
  _SettingPageState createState() => _SettingPageState();
}

class _SettingPageState extends TecfyState<SettingPage> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return widget.isPopup
        ? _getBody()
        : BasePage(
            context,
            AppLocale.translate('Settings'),
            'settings',
            isMobile: LayoutService.isMobile(context),
            child: _getBody(),
          );
  }

  Widget _getBody() {
    return SingleChildScrollView(
        child: Column(
      children: <Widget>[
        SizedBox(height: 15.0),
        _getItem(
            'Language',
            DropdownButtonHideUnderline(
                child: DropdownButton<Language>(
              value: LocalConfigService.language,
              items: [
                DropdownMenuItem(
                    child: TecfyText(trans('عربي')), value: Language.arabic),
                DropdownMenuItem(
                    child: TecfyText('English'), value: Language.english)
              ],
              onChanged: (v) async {
                LocalConfigService.language = v ?? Language.arabic;
                // if (v == Language.arabic) {
                //   AppNavigator.showLoading(context);
                //   await InitService.afterLoginInit();
                // }
              },
            )),
            null),
        SizedBox(height: 15.0),
        _getItem(
            'Connection Status',
            Row(
              children: <Widget>[
                TecfyText(trans('Status')),
                TecfyText(':'),
                SizedBox(width: 15.0),
                ConnectionService.getConnectionIconStream(),
              ],
            ),
            null),
        SizedBox(height: 15.0),
        _getItem(
            'Lock Timeout',
            DropdownButtonHideUnderline(
                child: DropdownButton(
              value: ConfigService.getValueInt('LockTimeout'),
              items: [
                DropdownMenuItem(child: TecfyText(trans('Never')), value: 0),
                DropdownMenuItem(child: TecfyText(trans('30s')), value: 30),
                DropdownMenuItem(
                    child: TecfyText(trans('10m')), value: 10 * 60),
                DropdownMenuItem(child: TecfyText('30m'), value: 30 * 60),
                DropdownMenuItem(child: TecfyText('1h'), value: 60 * 60),
              ],
              onChanged: (int? v) async {
                // setState((){});
                await ConfigService.setValueInt('LockTimeout', v!);
                AppLocale.languageStreamController.add(
                    LocalConfigService.isArabic
                        ? Language.arabic
                        : Language.english);
              },
            )),
            null,
            tooltipMessage: LocalConfigService.isArabic
                ? 'قفل '
                    'البرنامج لمدة معينة لحماية بيانات حسابك'
                : 'Lock Program for '
                    'specific time to secure your account'),
        SizedBox(
          height: 15.0,
        ),
        !PlatformService.isSupportLocalDBSupported
            ? Container()
            : _getItem(
                'Operation Mode',
                Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Expanded(
                          child: DropdownButtonHideUnderline(
                              child: DropdownButton<OperationMode>(
                        value: LocalConfigService.operationMode,
                        items: [
                          DropdownMenuItem(
                              child: TecfyText(trans('Online Mode')),
                              value: OperationMode.online),
                          DropdownMenuItem(
                              child: TecfyText(
                                  trans('Offline: Cache Required Data Only')),
                              value: OperationMode.offline_cache_required),
                          DropdownMenuItem(
                              child: TecfyText(trans('Offline: Cache Last 3 '
                                  'months')),
                              value: OperationMode.offline_cache_3months),
                          DropdownMenuItem(
                              child: TecfyText(trans('Offline: Cache Last 6 '
                                  'months')),
                              value: OperationMode.offline_cache_6months),
                          DropdownMenuItem(
                              child: TecfyText(trans('Offline: Cache Last 12 '
                                  'months')),
                              value: OperationMode.offline_cache_12months),
                          DropdownMenuItem(
                              child: TecfyText(trans('Offline: Cache All '
                                  'Data')),
                              value: OperationMode.offline_cache_all),
                        ],
                        onChanged: (v) async {
                          if (LocalConfigService.operationMode !=
                                  OperationMode.online &&
                              v == OperationMode.online) {
                            // make sure nothing in cache
                            try {
                              int pending =
                                  await TecfySyncService.getUnpostedCount();
                              if (pending > 0) {
                                var result = await AppNavigator.confirmMessage(
                                    context,
                                    'You have $pending local items not posted to server!!!!',
                                    message: AppLocale.translate(
                                        'Are you sure you want to logout?'));
                                if (!result) return;
                              }
                            } catch (e) {}
                          } else if (LocalConfigService.operationMode ==
                                  OperationMode.online &&
                              v != OperationMode.online) {
                            // re-create database
                            LocalConfigService.operationMode =
                                v ?? OperationMode.online;
                            AppNavigator.showLoading(context);
                            await DatabaseService.deleteDatabaseFile();
                            await EntityService.initEntities();
                            await DatabaseService.init();
                            AppNavigator.pop(context);
                          }
                          LocalConfigService.operationMode =
                              v ?? OperationMode.online;
                          setState(() {});
                        },
                      ))),
                    ]),
                LocalConfigService.operationMode != OperationMode.online
                    ? IconButton(
                        tooltip: trans('Show'),
                        icon: Icon(Icons.remove_red_eye_outlined),
                        onPressed: () async {
                          await AppNavigator.navigateTo(
                              context, () => LocalRecordsPage());
                        })
                    : Container()),
        SizedBox(height: 15.0),
        ConnectionService.isOnlineMode
            ? Container()
            : _getItem(
                'Unposted Items',
                Row(
                  children: <Widget>[
                    TecfyText(trans('Unposted Items')),
                    Expanded(child: SizedBox()),
                    TecfySyncService.getSyncIcon(context, false),
                  ],
                ),
                IconButton(
                    tooltip: trans('Show'),
                    icon: Icon(Icons.remove_red_eye_outlined),
                    onPressed: () async {
                      await AppNavigator.navigateTo(context, () => SyncPage());
                    })),
        SizedBox(height: 15.0),
        _getItem(
            'Account Settings',
            Row(
              children: <Widget>[
                TecfyText(trans('Name')),
                TecfyText(':'),
                SizedBox(width: 15.0),
                Expanded(
                    child: TecfyText(
                  LocalConfigService.user?.fullName ?? trans("Guest"),
                  maxLines: 1,
                  softWrap: true,
                  overflow: TextOverflow.clip,
                )),
              ],
            ),
            IconButton(
                tooltip: trans('Update Info'),
                icon: Icon(Icons.edit),
                onPressed: () async {
                  await AppNavigator.navigateTo(context, () => AccountPage());
                })),
        SizedBox(height: 15.0),
        _getItem(
            'Enable Expert Mode',
            Switch(
                value: ConfigService.getValueBool('ExpertMode'),
                onChanged: (v) {
                  ConfigService.setValueBool('ExpertMode', v);
                  setState(() {});
                }),
            null),
        SizedBox(height: 15.0),
        _getItem(
            'Enable Development Mode',
            Switch(
                value: ConfigService.getValueBool('DevelopmentMode'),
                onChanged: (v) {
                  ConfigService.setValueBool('DevelopmentMode', v);
                  setState(() {
                    //AppNavigator.navigateToNamed(context, '/');
                    Navigator.pushNamedAndRemoveUntil(
                        context, '/', (route) => false);
                  });
                }),
            null,
            tooltipMessage: LocalConfigService.isArabic
                ? 'يمكنك تفعيل '
                    'هذه الخاصية إذا كنت تريد تغير النص عن طريق الضغطة المطولة علي أي'
                    ' نص في البرنامج'
                : 'You can active it if you want to change whole '
                    'labels in application by holding long press on any text'),
        SizedBox(height: 15.0),
      ],
    ));
  }

  Widget _getItem(String title, Widget child, Widget? tools,
      {String? tooltipMessage}) {
    return Card(
      margin: EdgeInsets.symmetric(horizontal: 15.0),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: <Widget>[
          Container(
            height: 45.0,
            color: ThemeService.backgroundSecondColor,
            child: Padding(
                padding: EdgeInsets.symmetric(horizontal: 10),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    Align(
                      alignment: LocalConfigService.isArabic
                          ? Alignment.centerRight
                          : Alignment.centerLeft,
                      child: TecfyText(
                        AppLocale.translate(title),
                        style: Theme.of(context).textTheme.caption,
                      ),
                    ),
                    SizedBox(
                      width: 20,
                    ),
                    if (tooltipMessage != null)
                      Tooltip(
                        message: tooltipMessage,
                        child: Icon(
                          Icons.info_outline_rounded,
                          color: Colors.grey.shade500,
                        ),
                      ),
                    tools ?? const SizedBox()
                  ],
                )),
          ),
          //item('Account Information', ()=>AccountPage())
          Container(
            height: 70.0,
            color: Colors.white,
            margin: EdgeInsets.symmetric(horizontal: 10),
            child: Align(
                alignment: LocalConfigService.isArabic
                    ? Alignment.centerRight
                    : Alignment.centerLeft,
                child: child),
          )
        ],
      ),
    );
  }
}

==> tecfy_corev2_package-1.1.109.tar.gz: lib/views/home/setting.dart <==
part of tecfy_corev2_client_package;

class SettingPage extends StatefulWidget {
  final bool isPopup;
  SettingPage(this.isPopup, {Key? key}) : super(key: key);
  @override
  _SettingPageState createState() => _SettingPageState();
}

class _SettingPageState extends TecfyState<SettingPage> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return widget.isPopup
        ? _getBody()
        : BasePage(
            context,
            AppLocale.translate('Settings'),
            'settings',
            isMobile: LayoutService.isMobile(context),
            child: _getBody(),
          );
  }

  Widget _getBody() {
    return SingleChildScrollView(
        child: Column(
      children: <Widget>[
        SizedBox(height: 15.0),
        _getItem(
            'Language',
            DropdownButtonHideUnderline(
                child: DropdownButton<Language>(
              value: LocalConfigService.language,
              items: [
                DropdownMenuItem(
                    child: TecfyText(trans('عربي')), value: Language.arabic),
                DropdownMenuItem(
                    child: TecfyText('English'), value: Language.english)
              ],
              onChanged: (v) async {
                LocalConfigService.language = v ?? Language.arabic;
                // if (v == Language.arabic) {
                //   AppNavigator.showLoading(context);
                //   await InitService.afterLoginInit();
                // }
              },
            )),
            null),
        SizedBox(height: 15.0),
        _getItem(
            'Connection Status',
            Row(
              children: <Widget>[
                TecfyText(trans('Status')),
                TecfyText(':'),
                SizedBox(width: 15.0),
                ConnectionService.getConnectionIconStream(),
              ],
            ),
            null),
        SizedBox(height: 15.0),
        _getItem(
            'Lock Timeout',
            DropdownButtonHideUnderline(
                child: DropdownButton(
              value: ConfigService.getValueInt('LockTimeout'),
              items: [
                DropdownMenuItem(child: TecfyText(trans('Never')), value: 0),
                DropdownMenuItem(child: TecfyText(trans('30s')), value: 30),
                DropdownMenuItem(
                    child: TecfyText(trans('10m')), value: 10 * 60),
                DropdownMenuItem(child: TecfyText('30m'), value: 30 * 60),
                DropdownMenuItem(child: TecfyText('1h'), value: 60 * 60),
              ],
              onChanged: (int? v) async {
                // setState((){});
                await ConfigService.setValueInt('LockTimeout', v!);
                AppLocale.languageStreamController.add(
                    LocalConfigService.isArabic
                        ? Language.arabic
                        : Language.english);
              },
            )),
            null,
            tooltipMessage: LocalConfigService.isArabic
                ? 'قفل '
                    'البرنامج لمدة معينة لحماية بيانات حسابك'
                : 'Lock Program for '
                    'specific time to secure your account'),
        SizedBox(
          height: 15.0,
        ),
        !PlatformService.isSupportLocalDBSupported
            ? Container()
            : _getItem(
                'Operation Mode',
                Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Expanded(
                          child: DropdownButtonHideUnderline(
                              child: DropdownButton<OperationMode>(
                        value: LocalConfigService.operationMode,
                        items: [
                          DropdownMenuItem(
                              child: TecfyText(trans('Online Mode')),
                              value: OperationMode.online),
                          DropdownMenuItem(
                              child: TecfyText(
                                  trans('Offline: Cache Required Data Only')),
                              value: OperationMode.offline_cache_required),
                          DropdownMenuItem(
                              child: TecfyText(trans('Offline: Cache Last 3 '
                                  'months')),
                              value: OperationMode.offline_cache_3months),
                          DropdownMenuItem(
                              child: TecfyText(trans('Offline: Cache Last 6 '
                                  'months')),
                              value: OperationMode.offline_cache_6months),
                          DropdownMenuItem(
                              child: TecfyText(trans('Offline: Cache Last 12 '
                                  'months')),
                              value: OperationMode.offline_cache_12months),
                          DropdownMenuItem(
                              child: TecfyText(trans('Offline: Cache All '
                                  'Data')),
                              value: OperationMode.offline_cache_all),
                        ],
                        onChanged: (v) async {
                          if (LocalConfigService.operationMode !=
                                  OperationMode.online &&
                              v == OperationMode.online) {
                            // make sure nothing in cache
                            try {
                              int pending =
                                  await TecfySyncService.getUnpostedCount();
                              if (pending > 0) {
                                var result = await AppNavigator.confirmMessage(
                                    context,
                                    'You have $pending local items not posted to server!!!!',
                                    message: AppLocale.translate(
                                        'Are you sure you want to logout?'));
                                if (!result) return;
                              }
                            } catch (e) {}
                          } else if (LocalConfigService.operationMode ==
                                  OperationMode.online &&
                              v != OperationMode.online) {
                            // re-create database
                            LocalConfigService.operationMode =
                                v ?? OperationMode.online;
                            AppNavigator.showLoading(context);
                            // await DatabaseService.deleteDatabaseFile();
                            await EntityService.initEntities();
                            await DatabaseService.init();
                            AppNavigator.pop(context);
                          }
                          LocalConfigService.operationMode =
                              v ?? OperationMode.online;
                          setState(() {});
                        },
                      ))),
                    ]),
                LocalConfigService.operationMode != OperationMode.online
                    ? IconButton(
                        tooltip: trans('Show'),
                        icon: Icon(Icons.remove_red_eye_outlined),
                        onPressed: () async {
                          await AppNavigator.navigateTo(
                              context, () => LocalRecordsPage());
                        })
                    : Container()),
        SizedBox(height: 15.0),
        ConnectionService.isOnlineMode
            ? Container()
            : _getItem(
                'Unposted Items',
                Row(
                  children: <Widget>[
                    TecfyText(trans('Unposted Items')),
                    Expanded(child: SizedBox()),
                    TecfySyncService.getSyncIcon(context, false),
                  ],
                ),
                IconButton(
                    tooltip: trans('Show'),
                    icon: Icon(Icons.remove_red_eye_outlined),
                    onPressed: () async {
                      await AppNavigator.navigateTo(context, () => SyncPage());
                    })),
        SizedBox(height: 15.0),
        _getItem(
            'Account Settings',
            Row(
              children: <Widget>[
                TecfyText(trans('Name')),
                TecfyText(':'),
                SizedBox(width: 15.0),
                Expanded(
                    child: TecfyText(
                  LocalConfigService.user?.fullName ?? trans("Guest"),
                  maxLines: 1,
                  softWrap: true,
                  overflow: TextOverflow.clip,
                )),
              ],
            ),
            IconButton(
                tooltip: trans('Update Info'),
                icon: Icon(Icons.edit),
                onPressed: () async {
                  await AppNavigator.navigateTo(context, () => AccountPage());
                })),
        SizedBox(height: 15.0),
        _getItem(
            'Enable Expert Mode',
            Switch(
                value: ConfigService.getValueBool('ExpertMode'),
                onChanged: (v) {
                  ConfigService.setValueBool('ExpertMode', v);
                  setState(() {});
                }),
            null),
        SizedBox(height: 15.0),
        _getItem(
            'Enable Development Mode',
            Switch(
                value: ConfigService.getValueBool('DevelopmentMode'),
                onChanged: (v) {
                  ConfigService.setValueBool('DevelopmentMode', v);
                  setState(() {
                    //AppNavigator.navigateToNamed(context, '/');
                    Navigator.pushNamedAndRemoveUntil(
                        context, '/', (route) => false);
                  });
                }),
            null,
            tooltipMessage: LocalConfigService.isArabic
                ? 'يمكنك تفعيل '
                    'هذه الخاصية إذا كنت تريد تغير النص عن طريق الضغطة المطولة علي أي'
                    ' نص في البرنامج'
                : 'You can active it if you want to change whole '
                    'labels in application by holding long press on any text'),
        SizedBox(height: 15.0),
      ],
    ));
  }

  Widget _getItem(String title, Widget child, Widget? tools,
      {String? tooltipMessage}) {
    return Card(
      margin: EdgeInsets.symmetric(horizontal: 15.0),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: <Widget>[
          Container(
            height: 45.0,
            color: ThemeService.backgroundSecondColor,
            child: Padding(
                padding: EdgeInsets.symmetric(horizontal: 10),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    Align(
                      alignment: LocalConfigService.isArabic
                          ? Alignment.centerRight
                          : Alignment.centerLeft,
                      child: TecfyText(
                        AppLocale.translate(title),
                        style: Theme.of(context).textTheme.caption,
                      ),
                    ),
                    SizedBox(
                      width: 20,
                    ),
                    if (tooltipMessage != null)
                      Tooltip(
                        message: tooltipMessage,
                        child: Icon(
                          Icons.info_outline_rounded,
                          color: Colors.grey.shade500,
                        ),
                      ),
                    tools ?? const SizedBox()
                  ],
                )),
          ),
          //item('Account Information', ()=>AccountPage())
          Container(
            height: 70.0,
            color: Colors.white,
            margin: EdgeInsets.symmetric(horizontal: 10),
            child: Align(
                alignment: LocalConfigService.isArabic
                    ? Alignment.centerRight
                    : Alignment.centerLeft,
                child: child),
          )
        ],
      ),
    );
  }
}
